@@ -1,9 +1,9 @@
+from .arg import Arg, arg
 from .choices import Choices, get_choices_from, get_choices_from_class
-from .param import Param, param
-from .parser import Binding, Bindings, Parser, SubParser, SubParsers
+from .parser import Binding, Bindings, Parser, SubParser, SubParserGroup
 from .typed_args import TypedArgs, WithUnionType, validate_type_union
 
-VERSION = "0.2.3"
+VERSION = "0.2.4"
 
 __all__ = [
     "Choices",
@@ -14,9 +14,9 @@ __all__ = [
     "validate_type_union",
     "Parser",
     "SubParser",
-    "SubParsers",
-    "Param",
-    "param",
+    "SubParserGroup",
+    "Arg",
+    "arg",
     "Binding",
     "Bindings",
 ]
